@@ -69,6 +69,7 @@
 
 #define DXCB_PLUGIN_KEY "dxcb"
 #define DXCB_PLUGIN_SYMBOLIC_PROPERTY "_d_isDxcb"
+#define QT_THEME_CONFIG_PATH "D_QT_THEME_CONFIG_PATH"
 
 DCORE_USE_NAMESPACE
 
@@ -79,16 +80,24 @@ DApplicationPrivate::DApplicationPrivate(DApplication *q) :
 {
 #ifdef Q_OS_LINUX
     StartupNotificationMonitor *monitor = StartupNotificationMonitor::instance();
-    QObject::connect(monitor, &StartupNotificationMonitor::appStartup, [this, q](const QString id) {
-        m_monitoredStartupApps.append(id);
-        q->setOverrideCursor(Qt::WaitCursor);
-    });
-    QObject::connect(monitor, &StartupNotificationMonitor::appStartupCompleted, [this, q](const QString id) {
+    auto cancelNotification = [this, q](const QString id) {
         m_monitoredStartupApps.removeAll(id);
         if (m_monitoredStartupApps.isEmpty()) {
             q->setOverrideCursor(Qt::ArrowCursor);
         }
+    };
+    QObject::connect(monitor, &StartupNotificationMonitor::appStartup,
+                     q, [this, q, cancelNotification](const QString id) {
+        m_monitoredStartupApps.append(id);
+        q->setOverrideCursor(Qt::WaitCursor);
+        // Set a timeout of 15s in case that some apps like pamac-tray started
+        // with StartupNotify but don't show a window after startup finished.
+        QTimer::singleShot(15 * 1000, q, [id, cancelNotification](){
+            cancelNotification(id);
+        });
     });
+    QObject::connect(monitor, &StartupNotificationMonitor::appStartupCompleted,
+                     q, cancelNotification);
 #endif
 }
 
@@ -220,14 +229,14 @@ bool DApplicationPrivate::loadDtkTranslator(QList<QLocale> localeFallback)
     q->installTranslator(qtbaseTranslator);
 
     QList<DPathBuf> translateDirs;
-    auto dtkwidgetDir = "dtkwidget";
-    auto dtkwidgetName = "dtkwidget2";
+    auto dtkwidgetDir = DWIDGET_TRANSLATIONS_DIR;
+    auto dtkwidgetName = "dtkwidget";
 
     //("/home/user/.local/share", "/usr/local/share", "/usr/share")
     auto dataDirs = DStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
     for (const auto &path : dataDirs) {
         DPathBuf DPathBuf(path);
-        translateDirs << DPathBuf / dtkwidgetDir / "translations";
+        translateDirs << DPathBuf / dtkwidgetDir;
     }
 
     DPathBuf runDir(q->applicationDirPath());
@@ -281,6 +290,51 @@ bool DApplicationPrivate::loadTranslator(QList<DPathBuf> translateDirs, const QS
     return false;
 }
 
+void DApplicationPrivate::resetApplicationThemeType()
+{
+    D_QC(DApplication);
+    // 在 DThemeManager 初始化期间会调用 QApplicationi::setStyle
+    // 这将导致应用程序的调色板发生变化，因此先初始化DThemeManager对象
+    // 之后再获取调色板中的背景色
+    DThemeManager *tm = DThemeManager::instance();
+
+    // tm为空说明DThemeManager对象正在被初始化
+    if (!tm) {
+        return;
+    }
+
+    const QColor &window_background = q->palette().background().color();
+
+    // 颜色无效时不处理（窗口背景可能为图片）
+    if (!window_background.isValid()) {
+        return;
+    }
+
+    DThemeManager::ThemeType type = DThemeManager::toThemeType(window_background);
+    tm->setThemeType(type);
+}
+
+void DApplicationPrivate::resetWindowThemeType(QWidget *window)
+{
+    D_QC(DApplication);
+
+    // 如果窗口未自定义调色板，则清除其“主题类型”的设置
+    if (!window->testAttribute(Qt::WA_SetPalette)) {
+        DThemeManager::instance()->setThemeType(window, DThemeManager::UnknownType);
+        return;
+    }
+
+    const QColor &window_background = window->palette().background().color();
+
+    // 颜色无效时不处理（窗口背景可能为图片）
+    if (!window_background.isValid()) {
+        return;
+    }
+
+    DThemeManager::ThemeType type = DThemeManager::toThemeType(window_background);
+    DThemeManager::instance()->setThemeType(window, type);
+}
+
 bool DApplicationPrivate::isUserManualExists()
 {
 #ifdef Q_OS_LINUX
@@ -329,6 +383,24 @@ bool DApplicationPrivate::isUserManualExists()
  *
  * \~chinese \fn DApplication::iconThemeChanged()
  * \~chinese \brief iconThemeChanged 信号会在系统图标主题发生改变的时候被触发。
+ *
+ * \~chinese \fn DApplication::screenDevicePixelRatioChanged(QScreen *screen)
+ * \~chinese \brief screenDevicePixelRatioChanged 信号会在对应屏幕的缩放比可能发现变化
+ * \~chinese 时触发。
+ *
+ * \~chinese 依赖于 deepin 平台主题插件（dde-qt5integration 包中提供），实时更改
+ * \~chinese 屏幕缩放比是通过更改配置文件 ~/.config/deepin/qt-theme.ini 实现，与此相关的
+ * \~chinese 配置项有三个：
+ * \~chinese - ScreenScaleFactors：多屏幕设置不同缩放比，值格式和环境变量QT_SCREEN_SCALE_FACTORS一致
+ * \~chinese - ScaleFactor: 设置所有屏幕缩放比，值格式和环境变量QT_SCALE_FACTOR一致
+ * \~chinese - ScaleLogcailDpi：指定屏幕逻辑dpi，可影响仅设置了 point size 的 QFont 的绘制大小。
+ * \~chinese 未设置此值时，默认会在 \a ScreenScaleFactors 值改变后将屏幕逻辑dpi更改为主屏默认值，一般情况下，不需要设置此值。
+ * \~chinese \a ScreenScaleFactors 和 \a ScaleFactor 的值改变后，会触发所有屏幕的 QScreen::geometryChanged, 且会根据当前缩放
+ * \~chinese 更新所有QWindow的geometry（更新时保持窗口的真实大小不变，新窗口大小=窗口真实大小/新的缩放比）。另外，可在构造
+ * \~chinese DApplication 对象之前设置 \a Qt::AA_DisableHighDpiScaling 为 true，或添加环境变量 \a D_DISABLE_RT_SCREEN_SCALE
+ * \~chinese 禁用实时缩放的支持。
+ *
+ * \~chinese \sa QScreen::devicePixelRatio
  */
 
 /**
@@ -393,6 +465,9 @@ DApplication::DApplication(int &argc, char **argv) :
             QTapAndHoldGesture::setTimeout(gsettings.get("longpress-duration").toInt() - 100);
     }
 #endif
+
+    // 初始化窗口主题类型
+    d_func()->resetApplicationThemeType();
 }
 
 
@@ -632,6 +707,46 @@ void DApplication::registerDDESession()
 #endif
 }
 
+/*!
+ * \~chinese \brief DApplication::customQtThemeConfigPathByUserHome
+ * \~chinese 根据用户家目录设置Qt主题配置文件的目录。
+ * \~chinese \param home 家目录，不要以 "/" 结尾
+ * \~chinese \warning 必须在构造 DApplication 对象之前调用
+ * \~chinese \sa DApplication::customQtThemeConfigPathByUserHome
+ */
+void DApplication::customQtThemeConfigPathByUserHome(const QString &home)
+{
+    customQtThemeConfigPath(home + "/.config");
+}
+
+/*!
+ * \~chinese \brief DApplication::customQtThemeConfigPath
+ * \~chinese 自定义Qt主题配置文件的路径。
+ *
+ * \~chinese 默认文件通常为 "~/.config/deepin/qt-theme.ini"
+ * \~chinese 其中包含应用的图标主题、字体、、屏幕缩放等相关的配置项。可应用于以root用户启动的
+ * \~chinese 应用，需要跟随某个一般用户的主题设置项。
+ * \~chinese \a path 中不包含 "/deepin/qt-theme.ini" 部分，如：path = "/tmp"，
+ * \~chinese 则配置文件路径为："/tmp/deepin/qt-theme.ini"。
+ * \~chinese \param path 不要以 "/" 结尾
+ * \~chinese \warning 必须在构造 DApplication 对象之前调用
+ */
+void DApplication::customQtThemeConfigPath(const QString &path)
+{
+    Q_ASSERT_X(!qApp, "DApplication::customQtThemeConfigPath", "Must call before QGuiApplication defined object");
+    qputenv(QT_THEME_CONFIG_PATH, path.toLocal8Bit());
+}
+
+/*!
+ * \~chinese \brief DApplication::customizedQtThemeConfigPath
+ * \~chinese \return 返回自定义的 Qt 主题配置文件路径，未设置过此路径时返回为空。
+ * \~chinese \sa DApplication::customQtThemeConfigPath
+ */
+QString DApplication::customizedQtThemeConfigPath()
+{
+    return QString::fromLocal8Bit(qgetenv(QT_THEME_CONFIG_PATH));
+}
+
 /**
  * \~english @brief DApplication::productName returns the product name of this application.
  *
@@ -1020,7 +1135,8 @@ static inline bool basePrintPropertiesDialog(const QWidget *w)
 
 bool DApplication::notify(QObject *obj, QEvent *event)
 {
-    if (event->type() == QEvent::PolishRequest) {
+    switch((int)event->type()) {
+    case QEvent::PolishRequest: {
         // Fixed the style for the menu widget to dlight
         // ugly code will no longer needed.
         static QStyle *light_style = nullptr;
@@ -1064,10 +1180,33 @@ bool DApplication::notify(QObject *obj, QEvent *event)
             }
         }
 #endif
-    } else if (event->type() == QEvent::ParentChange) {
+        break;
+    }
+    case QEvent::ParentChange: {
         if (QWidget *widget = qobject_cast<QWidget *>(obj)) {
             DThemeManager::instance()->updateThemeOnParentChanged(widget);
         }
+        break;
+    }
+    // 处理应用程序和主窗口的调色板变化事件，以此更新程序/窗口的主题类型
+    case QEvent::ApplicationPaletteChange: {
+        // 只处理发送给application对象的事件
+        if (obj == this) {
+            D_D(DApplication);
+            d->resetApplicationThemeType();
+        }
+        break;
+    }
+    case QEvent::PaletteChange: {
+        D_D(DApplication);
+
+        if (QWidget *window = qobject_cast<QWidget*>(obj)) {
+            if (window->isTopLevel()) {
+                d->resetWindowThemeType(window);
+            }
+        }
+        break;
+    }
     }
 
     return QApplication::notify(obj, event);
