@@ -52,6 +52,13 @@ bool DBlurEffectWidgetPrivate::isBehindWindowBlendMode() const
            || q->isTopLevel();
 }
 
+bool DBlurEffectWidgetPrivate::isFull() const
+{
+    D_QC(DBlurEffectWidget);
+
+    return full || (q->isTopLevel() && !(blurRectXRadius * blurRectYRadius) && maskPath.isEmpty());
+}
+
 void DBlurEffectWidgetPrivate::addToBlurEffectWidgetHash()
 {
     D_QC(DBlurEffectWidget);
@@ -108,6 +115,10 @@ void DBlurEffectWidgetPrivate::setMaskColor(const QColor &color)
     if (isBehindWindowBlendMode()) {
         maskColor.setAlpha(DWindowManagerHelper::instance()->hasBlurWindow() ? maskAlpha : MASK_COLOR_ALPHA_DEFAULT);
     }
+
+    D_Q(DBlurEffectWidget);
+
+    q->update();
 }
 
 bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
@@ -121,18 +132,44 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
     bool isExistMaskPath = false;
 
     Q_FOREACH (const DBlurEffectWidget *w, blurEffectWidgetList) {
+        if (!w->d_func()->blurEnabled) {
+            continue;
+        }
+
+        // 当存在一个模糊区域填充整个窗口时，不需要再考虑其它的控件，直接对此窗口开启全模糊即可
+        if (w->d_func()->isFull() && w->isVisible()) {
+            DPlatformWindowHandle handle(topLevelWidget);
+
+            if (!handle.enableBlurWindow()) {
+                handle.setEnableBlurWindow(true);
+            }
+
+            return true;
+        }
+
         if (!w->d_func()->maskPath.isEmpty() && w->isVisible()) {
             isExistMaskPath = true;
             break;
         }
     }
 
+    // 清理窗口背景模糊是否完全开启的状态
+    DPlatformWindowHandle handle(topLevelWidget);
+
+    if (handle.enableBlurWindow()) {
+        handle.setEnableBlurWindow(false);
+    }
+
     bool ok = false;
 
     if (isExistMaskPath) {
         QList<QPainterPath> pathList;
 
         Q_FOREACH (const DBlurEffectWidget *w, blurEffectWidgetList) {
+            if (!w->d_func()->blurEnabled) {
+                continue;
+            }
+
             if (!w->isVisible()) {
                 continue;
             }
@@ -150,13 +187,17 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
             pathList << p;
         }
 
-        ok = DPlatformWindowHandle::setWindowBlurAreaByWM(topLevelWidget, pathList);
+        ok = handle.setWindowBlurAreaByWM(pathList);
     } else {
         QVector<DPlatformWindowHandle::WMBlurArea> areaList;
 
         areaList.reserve(blurEffectWidgetList.size());
 
         Q_FOREACH (const DBlurEffectWidget *w, blurEffectWidgetList) {
+            if (!w->d_func()->blurEnabled) {
+                continue;
+            }
+
             if (!w->isVisible()) {
                 continue;
             }
@@ -168,7 +209,7 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
             areaList << dMakeWMBlurArea(r.x(), r.y(), r.width(), r.height(), w->blurRectXRadius(), w->blurRectYRadius());
         }
 
-        ok = DPlatformWindowHandle::setWindowBlurAreaByWM(topLevelWidget, areaList);
+        ok = handle.setWindowBlurAreaByWM(areaList);
     }
 
     if (blurEffectWidgetList.isEmpty()) {
@@ -266,6 +307,25 @@ bool DBlurEffectWidgetPrivate::updateWindowBlurArea(QWidget *topLevelWidget)
  * \~chinese \see DBlurEffectWidget::maskColor DPlatformWindowHandle::hasBlurWindow
  */
 
+/*!
+ * \~chinese \property DBlurEffectWidget::full
+ * \~chinese \brief 如果值为true，将模糊此控件所在顶层窗口的整个背景，而无论控件的大小和位置，否则使用控件的位置和大小
+ * \~chinese 设置顶层窗口的模糊区域。需要注意的时，当控件本身就是顶层窗口且未设置 blurRectXRadius 和 blurRectYRadius
+ * \~chinese 属性的情况下，无论 full 属性的值为多少，都将和值为 true 时的行为保持一致。
+ * \~chinese \note 可读可写
+ * \~chinese \note 此属性不影响蒙版的绘制区域
+ * \~chinese \note 只在模糊的混合模式为 BehindWindowBlend 时生效
+ * \~chinese \see DBlurEffectWidget::blurRectXRadius BlurEffectWidget::blurRectYRadius
+ * \~chinese \see DBlurEffectWidget::maskColor
+ * \~chinese \see DBlurEffectWidget::blendMode
+ */
+
+/*!
+ * \~chinese \property DBlurEffectWidget::blurEnabled
+ * \~chinese \brief 如果值为 true 则此控件的模糊设置生效，否则不生效
+ * \~chinese \note 可读可写
+ */
+
 /*!
  * \~chinese \fn DBlurEffectWidget::radiusChanged
  * \~chinese \brief 信号会在 radius 属性的值改变时被发送
@@ -516,6 +576,20 @@ void DBlurEffectWidget::setMaskPath(const QPainterPath &path)
     update();
 }
 
+bool DBlurEffectWidget::isFull() const
+{
+    D_DC(DBlurEffectWidget);
+
+    return d->full;
+}
+
+bool DBlurEffectWidget::blurEnabled() const
+{
+    D_DC(DBlurEffectWidget);
+
+    return d->blurEnabled;
+}
+
 void DBlurEffectWidget::setRadius(int radius)
 {
     D_D(DBlurEffectWidget);
@@ -609,8 +683,6 @@ void DBlurEffectWidget::setMaskAlpha(quint8 alpha) {
 
     d->setMaskAlpha(alpha);
 
-    update();
-
     Q_EMIT maskAlphaChanged(alpha);
 }
 
@@ -628,7 +700,6 @@ void DBlurEffectWidget::setMaskColor(QColor maskColor)
 
     d->maskColorType = CustomColor;
     d->setMaskColor(maskColor);
-    update();
 
     Q_EMIT maskColorChanged(maskColor);
 }
@@ -650,6 +721,33 @@ void DBlurEffectWidget::setMaskColor(DBlurEffectWidget::MaskColorType type)
     update();
 }
 
+void DBlurEffectWidget::setFull(bool full)
+{
+    D_D(DBlurEffectWidget);
+
+    if (d->full == full)
+        return;
+
+    d->full = full;
+    d->updateWindowBlurArea();
+
+    Q_EMIT fullChanged(full);
+}
+
+void DBlurEffectWidget::setBlurEnabled(bool blurEnabled)
+{
+    D_D(DBlurEffectWidget);
+
+    if (d->blurEnabled == blurEnabled)
+        return;
+
+    d->blurEnabled = blurEnabled;
+    d->updateWindowBlurArea();
+    update();
+
+    Q_EMIT blurEnabledChanged(d->blurEnabled);
+}
+
 DBlurEffectWidget::DBlurEffectWidget(DBlurEffectWidgetPrivate &dd, QWidget *parent)
     : QWidget(parent)
     , DObject(dd)
@@ -666,6 +764,9 @@ void DBlurEffectWidget::paintEvent(QPaintEvent *event)
 {
     D_D(DBlurEffectWidget);
 
+    if (!d->blurEnabled)
+        return;
+
     QPainter pa(this);
 
     if (d->blurRectXRadius > 0 || d->blurRectYRadius > 0) {
