@@ -48,7 +48,7 @@ const int WindowHandleWidth = 10;
 
 const QColor BorderColor = QColor(0, 0, 0, 60);
 const QColor BackgroundTopColor = QColor(255, 255, 255);
-const QColor BackgroundBottonColor = QColor(255, 255, 255);
+const QColor BackgroundButtonColor = QColor(255, 255, 255);
 
 const QColor TipsBorderColor = QColor(255, 255, 255, 255 * 0.2);
 const QColor TipsBackground = QColor(0, 0, 0);
@@ -244,8 +244,6 @@ DBorderlessWidget::DBorderlessWidget(DBorderlessWidgetPrivate &dd, QWidget *pare
     QWidget::setMouseTracking(true);
 
     QWidget::setAttribute(Qt::WA_TranslucentBackground, true);
-    QWidget::setWindowFlags(Qt::Window | Qt::FramelessWindowHint);
-
     setWindowFlags(windowFlags());
     setDecorationFlags(decorationFlags());
 
@@ -255,12 +253,12 @@ DBorderlessWidget::DBorderlessWidget(DBorderlessWidgetPrivate &dd, QWidget *pare
 #endif
 #ifdef DTK_TITLE_DRAG_WINDOW
     connect(d->titlebar, &DTitlebar::mousePosMoving,
-    this, [ = ](Qt::MouseButton /*botton*/, QPoint pos) {
+    this, [ = ](Qt::MouseButton /*button*/, QPoint pos) {
         move(pos - d->m_LastMousePos);
     });
 
     connect(d->titlebar, &DTitlebar::mousePosPressed,
-    this, [ = ](Qt::MouseButtons /*botton*/, QPoint pos) {
+    this, [ = ](Qt::MouseButtons /*button*/, QPoint pos) {
         // TODO: fix margin
         pos.setY(pos.y() - 10);
         d->m_LastMousePos = pos - this->mapToParent(this->pos());
@@ -426,12 +424,12 @@ void DBorderlessWidget::showFullScreen()
 
 /*!
  * \~chinese @brief 移动窗口
- * \~chinese @param botton 接收Qt::MouseButton枚举值
+ * \~chinese @param button 接收Qt::MouseButton枚举值
  */
-void DBorderlessWidget::moveWindow(Qt::MouseButton botton)
+void DBorderlessWidget::moveWindow(Qt::MouseButton button)
 {
 #ifdef Q_OS_LINUX
-    XUtils::MoveWindow(this, botton);
+    XUtils::MoveWindow(this, button);
 #endif
 }
 
@@ -488,8 +486,9 @@ Qt::WindowFlags DBorderlessWidget::windowFlags()
 void DBorderlessWidget::setWindowFlags(Qt::WindowFlags type)
 {
     D_D(DBorderlessWidget);
+    QWidget::setWindowFlags(type | Qt::FramelessWindowHint);
     d->dwindowFlags = type;
-    d->titlebar->setWindowFlags(type);
+    d->titlebar->setWindowFlags(type &~ Qt::Window);
 }
 
 /*!
