@@ -25,7 +25,7 @@
 
 #include <cctype>
 
-DWIDGET_USE_NAMESPACE
+DWIDGET_BEGIN_NAMESPACE
 
 // static const variables
 const QString DShortcutEdit::DefaultTips = tr("Please input a new shortcut");
@@ -72,12 +72,13 @@ DShortcutEdit::DShortcutEdit(QWidget *parent)
 
 bool DShortcutEdit::eventFilter(QObject *o, QEvent *e)
 {
-    if (o == m_keysEdit && e->type() == QEvent::FocusOut && m_keysEdit->isVisible())
+    if (o == m_keysEdit && e->type() == QEvent::FocusOut && m_keysEdit->isVisible()) {
         toEchoMode();
-    else if (o == m_keysLabel && e->type() == QEvent::MouseButtonRelease && m_keysLabel->isVisible())
+    } else if (o == m_keysLabel && e->type() == QEvent::MouseButtonRelease && m_keysLabel->isVisible()) {
         toInputMode();
-    else if (o == m_keysEdit && e->type() == QEvent::KeyPress)
+    } else if (o == m_keysEdit && e->type() == QEvent::KeyPress) {
         shortcutKeyPress(static_cast<QKeyEvent *>(e));
+    }
 
     return false;
 }
@@ -89,8 +90,9 @@ void DShortcutEdit::clearShortcutKey()
 
 QSize DShortcutEdit::sizeHint() const
 {
-    if (!m_keysLabel || !m_keysEdit)
+    if (!m_keysLabel || !m_keysEdit) {
         return QSize();
+    }
 
     return QSize(qMax(m_keysLabel->sizeHint().width(), m_keysEdit->sizeHint().width()),
                  qMax(m_keysLabel->sizeHint().height(), m_keysEdit->sizeHint().height()));
@@ -98,10 +100,11 @@ QSize DShortcutEdit::sizeHint() const
 
 void DShortcutEdit::setShortcutKey(const QString &key)
 {
-    if (key.isEmpty())
+    if (key.isEmpty()) {
         m_keysLabel->setText(tr("None"));
-    else
+    } else {
         m_keysLabel->setText(convertShortcutKeys(key));
+    }
     m_keysEdit->setText(convertShortcutKeys(key));
     m_shortcutKeys = key;
 
@@ -140,9 +143,10 @@ const QList<QRegExp> &DShortcutEdit::getBlockShortcutKeysList() const
 
 bool DShortcutEdit::isValidShortcutKey(const QString &key)
 {
-    for (const QRegExp & k : m_blockedShortcutKeys)
-        if (key.contains(k))
+    for (const QRegExp &k : m_blockedShortcutKeys)
+        if (key.contains(k)) {
             return false;
+        }
 
     /*const QStringList keys = key.split("+");
 
@@ -173,8 +177,9 @@ void DShortcutEdit::toEchoMode()
 
     Q_EMIT shortcutKeysFinished(m_shortcutKeys);
 
-    if (!m_shortcutKeys.isEmpty() && !isValidShortcutKey(m_shortcutKeys))
+    if (!m_shortcutKeys.isEmpty() && !isValidShortcutKey(m_shortcutKeys)) {
         Q_EMIT invalidShortcutKey(m_shortcutKeys);
+    }
 }
 
 void DShortcutEdit::toInputMode() const
@@ -193,27 +198,32 @@ void DShortcutEdit::shortcutKeyPress(QKeyEvent *e)
 
     int state = 0;
     if ((e->modifiers() & Qt::ShiftModifier) && (e->text().isEmpty() ||
-                                                 !e->text().at(0).isPrint() ||
-                                                 e->text().at(0).isLetterOrNumber() ||
-                                                 e->text().at(0).isSpace()))
+            !e->text().at(0).isPrint() ||
+            e->text().at(0).isLetterOrNumber() ||
+            e->text().at(0).isSpace())) {
         state |= Qt::SHIFT;
-    if (e->modifiers() & Qt::ControlModifier)
+    }
+    if (e->modifiers() & Qt::ControlModifier) {
         state |= Qt::CTRL;
-    if (e->modifiers() & Qt::MetaModifier)
+    }
+    if (e->modifiers() & Qt::MetaModifier) {
         state |= Qt::META;
-    if (e->modifiers() & Qt::AltModifier)
+    }
+    if (e->modifiers() & Qt::AltModifier) {
         state |= Qt::ALT;
+    }
 
     int key = e->key() | state;
-    qDebug() << "keys: " << QKeySequence(key, 0, 0, 0).toString(QKeySequence::NativeText);
+//    qDebug() << "keys: " << QKeySequence(key, 0, 0, 0).toString(QKeySequence::NativeText);
     m_shortcutKeys = QKeySequence(key, 0, 0, 0).toString(QKeySequence::NativeText);
 
     //qDebug() << m_shortcutKeys << e->text() << e->key();
     //qDebug() << "keys: " << int(e->key() & ~(Qt::SHIFT | Qt::ControlModifier | Qt::META | Qt::ALT));
 
     // if pressed key is "Backspace", its means "clear all"
-    if (m_shortcutKeys == "Backspace")
+    if (m_shortcutKeys == "Backspace") {
         return clearShortcutKey();
+    }
 
     setShortcutKey(m_shortcutKeys);
 
@@ -221,19 +231,22 @@ void DShortcutEdit::shortcutKeyPress(QKeyEvent *e)
     qDebug() << "last: " << lastKey << lastKey.size();
 
     // if lastKey is not alt, shift, ctrl, meta, shortcut key is finished.
-    if (lastKey.size() == 2 && !lastKey.at(0).isLetter())
+    if (lastKey.size() == 2 && !lastKey.at(0).isLetter()) {
         return;
+    }
     if (lastKey != "Meta" && lastKey != "Ctrl" &&
-        lastKey != "Shift" && lastKey != "Alt")
+            lastKey != "Shift" && lastKey != "Alt") {
         toEchoMode();
+    }
 }
 
 QString DShortcutEdit::convertShortcutKeys(const QString &keys)
 {
     QString newKeys = keys;
 
-    for (const QString & k : m_keyMapping.keys())
+    for (const QString &k : m_keyMapping.keys()) {
         newKeys.replace(k, m_keyMapping[k]);
+    }
 
     return newKeys;
 }
@@ -243,19 +256,17 @@ DShortcutEditLabel::DShortcutEditLabel(QWidget *parent)
 {
     setEchoState(Normal);
 
-    connect(this, &DShortcutEditLabel::colorSettingChange, [this] () -> void {setEchoState(m_state);});
+    connect(this, &DShortcutEditLabel::colorSettingChange, [this]() -> void {setEchoState(m_state);});
 }
 
 void DShortcutEditLabel::setEchoState(const DShortcutEditLabel::EchoState state)
 {
     QColor c = m_colorNormal;
 
-    switch (state)
-    {
+    switch (state) {
     case Normal:    c = m_colorNormal;    break;
     case Hover:     c = m_colorHover;     break;
     case Invalid:   c = m_colorInvalid;   break;
-    default:        c = m_colorNormal;    break;
     }
 
     setStyleSheet(QString("color:%1;").arg(c.name()));
@@ -266,12 +277,16 @@ void DShortcutEditLabel::setEchoState(const DShortcutEditLabel::EchoState state)
 
 void DShortcutEditLabel::enterEvent(QEvent *)
 {
-    if (m_state == Normal)
+    if (m_state == Normal) {
         setEchoState(Hover);
+    }
 }
 
 void DShortcutEditLabel::leaveEvent(QEvent *)
 {
-    if (m_state == Hover)
+    if (m_state == Hover) {
         setEchoState(Normal);
+    }
 }
+
+DWIDGET_END_NAMESPACE
