@@ -35,6 +35,8 @@ DSpinnerPrivate::DSpinnerPrivate(DSpinner *qq)
     \~chinese \class DSpinner
     \~chinese \brief 可以使用 DSpinner 类快速创建用于指示加载中状态的旋转等待图标动画控件。
 
+    \~chinese \image html DSpinner.gif
+
     \~chinese DSpinner 提供了一个用于指示加载中状态的旋转等待图标动画控件。在创建图标后，使用 start() 即可开始图标旋转的动画。
 */
 
@@ -42,6 +44,8 @@ DSpinnerPrivate::DSpinnerPrivate(DSpinner *qq)
     \~english \class DSpinner
     \~english \brief Use DSpinner to create a widget with spinning animation for display a waiting state.
 
+    \~english \image html DSpinner.gif
+
     \~english DSpinner provide a spinning animation widget to indicate a waiting state. Call start() to start
     the spinning animation.
 */
