@@ -284,7 +284,12 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
     bool useDXcb = DPlatformWindowHandle::isEnabledDXcb(targetWindow());
     bool isFullscreen = targetWindow()->windowState().testFlag(Qt::WindowFullScreen);
 
-    bool showTitle = (type.testFlag(Qt::WindowTitleHint) || !useDXcb) && !embedMode;
+    bool forceShow = !useDXcb;
+#ifndef Q_OS_LINUX
+    forceShow = false;
+#endif
+
+    bool showTitle = (type.testFlag(Qt::WindowTitleHint) || forceShow) && !embedMode;
     if (titleLabel) {
         titleLabel->setVisible(showTitle);
     }
@@ -295,24 +300,28 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
     // Never show in embed/fullscreen
     bool forceHide = embedMode || isFullscreen;
 
-    bool showMin = (type.testFlag(Qt::WindowMinimizeButtonHint) || !useDXcb) && !forceHide;
+    bool showMin = (type.testFlag(Qt::WindowMinimizeButtonHint) || forceShow) && !forceHide;
     minButton->setVisible(showMin);
 
+
     bool allowResize = true;
+
     if (q->window() && q->window()->windowHandle()) {
         auto functions_hints = DWindowManagerHelper::getMotifFunctions(q->window()->windowHandle());
         allowResize = functions_hints.testFlag(DWindowManagerHelper::FUNC_RESIZE);
     }
 
-    bool showMax = (type.testFlag(Qt::WindowMaximizeButtonHint) || !useDXcb) && !forceHide && allowResize;
+    bool showMax = (type.testFlag(Qt::WindowMaximizeButtonHint) || forceShow) && !forceHide && allowResize;
+//    qDebug() << "max:"
+//             << "allowResize" << allowResize
+//             << "useDXcb" << useDXcb
+//             << "forceHide" << forceHide
+//             << "type.testFlag(Qt::WindowMaximizeButtonHint)" << type.testFlag(Qt::WindowMaximizeButtonHint);
     maxButton->setVisible(showMax);
 
-    bool showClose = (type.testFlag(Qt::WindowCloseButtonHint) || !useDXcb) && !forceHide;
+    bool showClose = (type.testFlag(Qt::WindowCloseButtonHint) || forceShow) && !forceHide;
     closeButton->setVisible(showClose);
 
-    bool showOption = (type.testFlag(Qt::WindowSystemMenuHint) || !useDXcb) && !isFullscreen;
-    optionButton->setVisible(showOption);
-
     buttonArea->adjustSize();
     buttonArea->resize(buttonArea->size());
 
@@ -323,10 +332,9 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
 
 void DTitlebarPrivate::updateButtonsFunc()
 {
-    optionButton->setDisabled(disableFlags.testFlag(Qt::WindowSystemMenuHint));
-
-    if (!targetWindowHandle)
+    if (!targetWindowHandle) {
         return;
+    }
 
     // 根据 disableFlags 更新窗口标志，而标题栏上具体按钮的开启/禁用状态只根据
     // 窗口标志改变后做更新，且窗口标志改变后也会同步更新 disableFlags 的值，
@@ -429,7 +437,7 @@ void DTitlebarPrivate::_q_onTopWindowMotifHintsChanged(quint32 winId)
 
     minButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_MINIMIZE));
     maxButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_MAXIMIZE)
-                            && functions_hints.testFlag(DWindowManagerHelper::FUNC_RESIZE));
+                          && functions_hints.testFlag(DWindowManagerHelper::FUNC_RESIZE));
     closeButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_CLOSE));
     // sync button state
 #if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
@@ -524,7 +532,7 @@ void DTitlebarPrivate::_q_quitActionTriggered()
 
 
 /*!
- *  \~english @brief DTitlebar::DTitlebar create an default widget with icon/title/and bottons
+ *  \~english @brief DTitlebar::DTitlebar create an default widget with icon/title/and buttons
  * @param parent
  */
 /*!
@@ -542,6 +550,12 @@ DTitlebar::DTitlebar(QWidget *parent) :
 
     D_D(DTitlebar);
     d->init();
+
+    // 默认只在普通窗口中显示窗口菜单按钮
+    if (parent && parent->window()->windowType() != Qt::Window) {
+        d->optionButton->hide();
+    }
+
     d->buttonArea->adjustSize();
     d->buttonArea->resize(d->buttonArea->size());
     d->titlePadding->setFixedSize(d->buttonArea->size());
@@ -1001,6 +1015,30 @@ void DTitlebar::resize(const QSize &sz)
     DTitlebar::resize(sz.width(), sz.height());
 }
 
+bool DTitlebar::menuIsVisible() const
+{
+    D_DC(DTitlebar);
+    return !d->optionButton->isVisible();
+}
+
+void DTitlebar::setMenuVisible(bool visible)
+{
+    D_D(DTitlebar);
+    d->optionButton->setVisible(visible);
+}
+
+bool DTitlebar::menuIsDisabled() const
+{
+    D_DC(DTitlebar);
+    return !d->optionButton->isEnabled();
+}
+
+void DTitlebar::setMenuDisabled(bool disabled)
+{
+    D_D(DTitlebar);
+    d->optionButton->setDisabled(disabled);
+}
+
 
 /*!
  * \~english \brief DTitlebar::setDisableFlags will disable button match flags.
