@@ -52,6 +52,11 @@ public:
     bool loadDtkTranslator(QList<QLocale> localeFallback);
     bool loadTranslator(QList<DPathBuf> translateDirs, const QString &name, QList<QLocale> localeFallback);
 
+    // 根据调色板中的窗口背景色重设程序的主题颜色“亮”/“暗”类型
+    void resetApplicationThemeType();
+    // 根据窗口自身的背景色重设其主题颜色的“亮”/“暗”类型
+    void resetWindowThemeType(QWidget *window);
+
     static bool isUserManualExists();
 public:
 // int m_pidLockFD = 0;
