@@ -36,7 +36,7 @@ public:
 public:
     void _q_showFileChooserDialog();
 
-    DFileChooserEdit::DialogDisplayPosition dialogDisplayPosition = DFileChooserEdit::FoloowParentWindow;
+    DFileChooserEdit::DialogDisplayPosition dialogDisplayPosition = DFileChooserEdit::FollowParentWindow;
     QFileDialog::FileMode fileMode = QFileDialog::ExistingFile;
     QStringList nameFilters;
 };
