@@ -24,6 +24,8 @@
 #include <QScrollArea>
 #include <QVBoxLayout>
 #include <QCoreApplication>
+#include <QScroller>
+#include <QMouseEvent>
 
 #include <DSettings>
 #include <DSettingsGroup>
@@ -76,6 +78,9 @@ Content::Content(QWidget *parent) :
     d->contentArea->setStyleSheet("QScrollArea{border: none; background-color: transparent; }");
 //    d->contentArea->setStyleSheet("QFrame{border: 1px solid red;}");
 
+    // 设置列表支持触屏滚动
+    QScroller::grabGesture(d->contentArea);
+
     d->contentFrame = new QWidget(this);
     d->contentFrame->setObjectName("SettingsContent");
     d->contentFrame->setStyleSheet("#SettingsContent{border: none; background-color: transparent; }");
@@ -223,4 +228,16 @@ void Content::updateSettings(const QByteArray &translateContext, QPointer<DTK_CO
     });
 }
 
+void Content::mouseMoveEvent(QMouseEvent *event)
+{
+    // 事件来源为 MouseEventSynthesizedByQt 时认为此事件为Touch事件合成而来
+    // 由于支持触屏下对视图的滚动，所以此处接收没有被处理的move事件，防止事件泄露
+    // 到主窗口后触发窗口移动动作
+    if (event->source() == Qt::MouseEventSynthesizedByQt) {
+        event->accept();
+
+        return;
+    }
+}
+
 DWIDGET_END_NAMESPACE
