@@ -41,7 +41,7 @@ Q_SIGNALS:
 
 public Q_SLOTS:
     void onSelectGroup(const QString &key);
-    void updateSettings(QPointer<DTK_CORE_NAMESPACE::DSettings> settings);
+    void updateSettings(const QByteArray &translateContext, QPointer<DTK_CORE_NAMESPACE::DSettings> settings);
 
 private:
     QScopedPointer<NavigationPrivate> d_ptr;
